.. hckr documentation master file, created by
   sphinx-quickstart on Wed Jun 12 20:06:39 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. click:: hckr.cli.cron:cron
   :prog: hckr cron
   :nested: full
